@@ -14,15 +14,15 @@ from compas.geometry import subtract_vectors
 from compas.geometry import add_vectors
 from compas.geometry import scale_vector
 
-from ._modify import mesh_update_attributes
-from ._modify import mesh_update_vertex_attributes
-from ._modify import mesh_update_face_attributes
-from ._modify import mesh_update_edge_attributes
-from ._modify import mesh_move_vertex
-from ._modify import mesh_move_vertices
-from ._modify import mesh_move_face
+from compas_rhino.objects._modify import mesh_update_attributes
+from compas_rhino.objects._modify import mesh_update_vertex_attributes
+from compas_rhino.objects._modify import mesh_update_face_attributes
+from compas_rhino.objects._modify import mesh_update_edge_attributes
+from compas_rhino.objects._modify import mesh_move_vertex
+from compas_rhino.objects._modify import mesh_move_vertices
+from compas_rhino.objects._modify import mesh_move_face
 
-from ._object import BaseObject
+from compas_rhino.objects._object import BaseObject
 
 
 __all__ = ['MeshObject']
@@ -572,11 +572,3 @@ class MeshObject(BaseObject):
         self.anchor = anchor
         self.location = vertex_xyz[anchor]
         return True
-
-
-# ============================================================================
-# Main
-# ============================================================================
-
-if __name__ == "__main__":
-    pass
